@@ -60,7 +60,7 @@ class SequenceGeneration():
                 if Js is None:
                     self.iJs = range(self.generative_model.PVJ.shape[1])
                 else:
-                    self.iJs = [dctVs[jj] for j in Js
+                    self.iJs = [dctJs[jj] for j in Js
                                 for jj in gene_map(j, self.genomic_data)]
                 if not self.write_restricted_recombination_model_VJ(tmp.name):
                     Exception("Error during model creation")
